# Python Whatsapp ADB

## Python utility methods for Whatsapp utilities through ADB commands.


### BUILD

python setup.py sdist
python setup.py bdist_wheel


### INSTALL

As a package:
pip install ./


Editable mode:

pip install -e ./
